@@ -27,7 +27,7 @@ def toDomain(link):
     return (re.sub(r'^(https?://)?(www\d?\.)?', '', link).split('/')+[''])[0].strip()
 
 
-def parse(page, domain=''):
+def parse(page, domain='', get_more_page=True, contact_page=None, about_page=None):
     result = {
         'title': '',
         'corpName': '',
@@ -102,11 +102,15 @@ def parse(page, domain=''):
     result['phone'] = ';'.join(set(re.findall(
         r'(\d{3}[-\.\s]??\d{3}[-\.\s]??\d{4}|\(\d{3}\)\s*\d{3}[-\.\s]??\d{4}|\d{3}[-\.\s]??\d{4})', vis)))
 
-    if not addresses and result['aboutLink']:
+    if not addresses and result['aboutLink'] and get_more_page:
         try:
-            res = requests.get(result['aboutLink'],
-                               timeout=15, headers=headers)
-            resvis = visiableText(res.content)
+            if not about_page:
+                res = requests.get(result['aboutLink'],
+                                timeout=15, headers=headers)
+                about_page = res.content
+                resvis = visiableText(res.content)
+            else:
+                resvis = visiableText(about_page)
             result['aboutText'] = resvis
             addresses = pyap.parse(resvis, country='CA')
             addresses += pyap.parse(resvis, country='US')
@@ -117,11 +121,14 @@ def parse(page, domain=''):
                 addresses = addressesNoAnd
         except Exception as e:
             pass
-    if not addresses and result['contactLink']:
+    if not addresses and result['contactLink'] and get_more_page:
         try:
-            res = requests.get(result['contactLink'],
-                               timeout=20, headers=headers)
-            resvis = visiableText(res.content)
+            if not contact_page:
+                res = requests.get(result['contactLink'],
+                                timeout=20, headers=headers)
+                resvis = visiableText(res.content)
+            else:
+                resvis = visiableText(contact_page)
             result['contactText'] = resvis
             addresses = pyap.parse(resvis, country='CA')
             addresses += pyap.parse(resvis, country='US')
@@ -139,11 +146,14 @@ def parse(page, domain=''):
             names = re.findall(namepattern, result['title'], re.I)
         except:
             pass
-    elif result['aboutLink'] and namepattern:
+    elif result['aboutLink'] and namepattern and get_more_page:
         try:
-            aboutres = requests.get(
-                result['aboutLink'], timeout=15, headers=headers)
-            aboutvis = visiableText(aboutres.content)
+            if not about_page:
+                aboutres = requests.get(
+                    result['aboutLink'], timeout=15, headers=headers)
+                aboutvis = visiableText(aboutres.content)
+            else:
+                aboutvis = visiableText(about_page)
             names = re.findall(namepattern, aboutvis, re.I)
         except:
             pass
@@ -164,7 +174,7 @@ def parse(page, domain=''):
     return result
 
 
-def standardScrape(url, parkingterms=[r'godaddy', r'domain is available for sale']):
+def standardScrape(url, parkingterms=[r'godaddy', r'domain is available for sale'], get_more_page=True):
     domain = toDomain(url)
     parkingpattern = re.compile('|'.join(parkingterms), re.I)
     try:
@@ -178,7 +188,7 @@ def standardScrape(url, parkingterms=[r'godaddy', r'domain is available for sale
         return {'statusCode':statusCode,"webstatus":"inactive"}, b''
     else:
         webstatus = 'active'
-        result = parse(res.content, domain=domain)
+        result = parse(res.content, domain=domain, get_more_page=get_more_page)
         result['redirectURL'] = toDomain(res.url)
         if re.findall(parkingpattern, result.get('homepageText','')):
             return {'statusCode':statusCode,"webstatus":"parking"}, b''
@@ -190,6 +200,6 @@ if __name__ == '__main__':
     # res = requests.get('http://keywebpmt.com', timeout=20, headers=headers)
     # result = parse(res.content)
     import kumihotools
-    result,_ = standardScrape('ixsystems.com', parkingterms=kumihotools.parkingterms)
+    result,_ = standardScrape('ixsystems.com', parkingterms=kumihotools.parkingterms,get_more_page=False)
     # result, content = standardScrape('http://keywebpmt.com')
     print(result)
\ No newline at end of file
